==> jc-1.4.0.tar.gz: javax/swing/border/AbstractBorder.h <==
// public abstract class javax.swing.border.AbstractBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_border_AbstractBorder_H_
#define _JC_javax_swing_border_AbstractBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_border_AbstractBorder$sub_refs	_jc_javax_swing_border_AbstractBorder$sub_refs;
typedef struct _jc_javax_swing_border_AbstractBorder$sub_nonrefs	_jc_javax_swing_border_AbstractBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_AbstractBorder$refs	_jc_javax_swing_border_AbstractBorder$refs;
typedef struct _jc_javax_swing_border_AbstractBorder$nonrefs	_jc_javax_swing_border_AbstractBorder$nonrefs;
typedef struct _jc_javax_swing_border_AbstractBorder$object	_jc_javax_swing_border_AbstractBorder$object;

typedef struct _jc_javax_swing_border_AbstractBorder$fields_struct	_jc_javax_swing_border_AbstractBorder$fields_struct;
typedef const struct _jc_javax_swing_border_AbstractBorder$vmethods	_jc_javax_swing_border_AbstractBorder$vmethods;
typedef const struct _jc_javax_swing_border_AbstractBorder$vtable	_jc_javax_swing_border_AbstractBorder$vtable;
typedef const struct _jc_javax_swing_border_AbstractBorder$vtype	_jc_javax_swing_border_AbstractBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_AbstractBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_AbstractBorder$fields_struct _jc_javax_swing_border_AbstractBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_AbstractBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_AbstractBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_AbstractBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_border_AbstractBorder$method$getInteriorRectangle$ad07219130a326f0(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, jint, jint, jint, jint);
extern jboolean _jc_javax_swing_border_AbstractBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *);
extern void _jc_javax_swing_border_AbstractBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$getInteriorRectangle$ad07219130a326f0;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$paintBorder$4a79b2eae89db578;

// Static methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_border_AbstractBorder$method$getInteriorRectangle$9c69c706d21ef26c(_jc_env *, struct _jc_java_awt_Component$object *, struct _jc_object *, jint, jint, jint, jint);

// Virtual methods structure
struct _jc_javax_swing_border_AbstractBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
	struct _jc_java_awt_Rectangle$object	*(*getInteriorRectangle$ad07219130a326f0)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, jint, jint, jint, jint);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_border_AbstractBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
};

// Vtype
struct _jc_javax_swing_border_AbstractBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_AbstractBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_AbstractBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_border_AbstractBorder$refs {
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_AbstractBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_AbstractBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
};

// Object instance structure
struct _jc_javax_swing_border_AbstractBorder$object {
	_jc_javax_swing_border_AbstractBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_AbstractBorder$vtype	*vtype;
	_jc_javax_swing_border_AbstractBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_AbstractBorder$vtype _jc_javax_swing_border_AbstractBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_AbstractBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_AbstractBorder$class_object;

#endif	/* _JC_javax_swing_border_AbstractBorder_H_ */

==> jc-1.4.6.tar.gz: javax/swing/border/AbstractBorder.h <==
// public abstract class javax.swing.border.AbstractBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_border_AbstractBorder_H_
#define _JC_javax_swing_border_AbstractBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_border_AbstractBorder$sub_refs	_jc_javax_swing_border_AbstractBorder$sub_refs;
typedef struct _jc_javax_swing_border_AbstractBorder$sub_nonrefs	_jc_javax_swing_border_AbstractBorder$sub_nonrefs;
typedef struct _jc_javax_swing_border_AbstractBorder$refs	_jc_javax_swing_border_AbstractBorder$refs;
typedef struct _jc_javax_swing_border_AbstractBorder$nonrefs	_jc_javax_swing_border_AbstractBorder$nonrefs;
typedef struct _jc_javax_swing_border_AbstractBorder$object	_jc_javax_swing_border_AbstractBorder$object;

typedef struct _jc_javax_swing_border_AbstractBorder$fields_struct	_jc_javax_swing_border_AbstractBorder$fields_struct;
typedef const struct _jc_javax_swing_border_AbstractBorder$vmethods	_jc_javax_swing_border_AbstractBorder$vmethods;
typedef const struct _jc_javax_swing_border_AbstractBorder$vtable	_jc_javax_swing_border_AbstractBorder$vtable;
typedef const struct _jc_javax_swing_border_AbstractBorder$vtype	_jc_javax_swing_border_AbstractBorder$vtype;

// Class fields structure
struct _jc_javax_swing_border_AbstractBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_border_AbstractBorder$fields_struct _jc_javax_swing_border_AbstractBorder$class_fields;

// Constructors
extern void _jc_javax_swing_border_AbstractBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_AbstractBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_border_AbstractBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_border_AbstractBorder$method$getInteriorRectangle$ad07219130a326f0(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_border_AbstractBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_border_AbstractBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$getInteriorRectangle$ad07219130a326f0;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_border_AbstractBorder$method_info$paintBorder$4a79b2eae89db578;

// Static methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_border_AbstractBorder$method$getInteriorRectangle$9c69c706d21ef26c(_jc_env *, struct _jc_java_awt_Component$object *, struct _jc_object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_border_AbstractBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Rectangle$object	*(*getInteriorRectangle$ad07219130a326f0)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_border_AbstractBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_border_AbstractBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
};

// Vtype
struct _jc_javax_swing_border_AbstractBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_border_AbstractBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_border_AbstractBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_border_AbstractBorder$refs {
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_border_AbstractBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_border_AbstractBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
};

// Object instance structure
struct _jc_javax_swing_border_AbstractBorder$object {
	_jc_javax_swing_border_AbstractBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_border_AbstractBorder$vtype	*vtype;
	_jc_javax_swing_border_AbstractBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_border_AbstractBorder$vtype _jc_javax_swing_border_AbstractBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_border_AbstractBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_border_AbstractBorder$class_object;

#endif	/* _JC_javax_swing_border_AbstractBorder_H_ */
